///////////////////////////////////////////////////////////////////////////////////////////////////////////////
//=============================================================================================================
// INTRODUCTION
//=============================================================================================================
//  Project/Example: Grump Grandpa (X02) 
//  Purpose: This project uses the Microphone to detect noise levels. If the noise levels are too loud for a 
//            period of time. Grandpa will be angry and start yelling (buzzer sounds).
//  License: GNU General Public License v3
//  Link: https://wiki.microduino.cc/index.php/Grumpy_Grandpa_(X02)
// 
//  Author(s): Microduino, Sonny Sung
//  E-mail(s): support at microduino.cc, sonny at microduino.cc
//
//  Version: 1.0
//  Date: ????/??/??
//  Notes: Initial version
//
//  Version: 1.1
//  Date: 2017/04/20
//  Notes: Updated for X02 Series kits.
//=============================================================================================================
// REQUIRED HARDWARE
//=============================================================================================================
//  COMPATIBLE KITS
//    [ ] 101 Basic Kit
//    [ ] 201 Advanced Kit
//    [ ] 301 Expert Kit
//    [*] 102 Basic Kit
//    [*] 202 Advanced Kit
//    [*] 302 Expert Kit
//    [*] Itty Bitty City Kit
//=============================================================================================================
//  MODULES
//    [1] Core, Core+, CoreUSB -OR- CoreRF
//    [1] mBattery -OR- USBTTL
//    [1] Sensor Hub
//  SENSORS/TRINKETS
//    [3] Sensor Cable
//    [1] Crash Sensor
//    [1] Microphone Sensor
//    [1] Buzzer
//  OTHER
//    [1] MicroUSB Cable
//=============================================================================================================
// SETUP
//=============================================================================================================
//  NOTE: When connecting sensor wires, push on the plastic connector and not on the wires. 
//          Pushing on the wire can damage them.
//
//  1. Connect the Crash Sensor to the Sensor Hub on Pin 4/5
//  2. Connect the Buzzer to the Sensor Hub on Pin 6/7
//  3. Connect the Microphone to the Sensor Hub on Pin A0/A1
//  4. Grab the mCookie USBTTL or mBattery and Stack the mCookie Core on top.
//  5. Stack the mCookie Sensor on top of that.
//  6. Plug in the MicroUSB cable to the mCookie USBTTL or mBattery to a computer.
//  7. Program the example by pressing "upload".
//=============================================================================================================
// USAGE
//=============================================================================================================
//  Cause enough noise (MIC_MIN) for a time period (NOISE_TIME) and this will anger Grandpa. Grandpa will start
//  yelling (making noise with the Buzzer). Once, Grandpa is angry. Calm him down by pressing the button.
//=============================================================================================================
// TWEAKING
//=============================================================================================================
//  "userDef.h" tab has configurable variables.
//  Visit https://wiki.microduino.cc/index.php/Grumpy_Grandpa_(X02)#Tweaking for further tweaking instructions.
//=============================================================================================================
// NOTES
//=============================================================================================================
//  Additional info at: https://wiki.microduino.cc/index.php/Grumpy_Grandpa_(X02)
///////////////////////////////////////////////////////////////////////////////////////////////////////////////

#include "userDef.h"
#include "key.h"

int voice_data;
long time, timer;

boolean buzzer_speak;

boolean add;
int i = 200;

void setup() {
  Serial.begin(9600);
  pinMode(MIC_PIN, INPUT);
  pinMode(KEY_PIN, INPUT);
  pinMode(BUZZER_PIN, OUTPUT);

  key_init();
}

void loop() {

  voice_data = analogRead(MIC_PIN);
  
  #ifdef DEBUG
    Serial.print("MIC value: ");
    Serial.println(voice_data);
  #endif
  
  if (voice_data > MIC_MIN)
  {
    if (millis() - time > NOISE_TIME )
    {
      voice_data = analogRead(MIC_PIN);
      if (voice_data > MIC_MIN)
      {
        #ifdef DEBUG
          Serial.println("I AM GRUMPY!");
        #endif
        buzzer_speak = true;
        i = 200;
      }
      time = millis();
    }
  }
  else
  time = millis();
  if (key_get(KEY_PIN, 0))
  {
    delay(200);
    buzzer_speak = false;
    time = millis();
  }
  if (buzzer_speak)
    buzzer();
  else
    noTone(BUZZER_PIN);
}

void buzzer()
{
  if (millis() - timer > 10)
  {
    if (!add)
    {
      i++;
      if (i >= 800)
        add = true;
    }
    else
    {
      i--;
      if (i <= 200)
        add = false;
    }
    tone(BUZZER_PIN, i);
    timer = millis();
  }
}
